@@ -29,7 +29,13 @@ from spyder.utils.programs import TEMPDIR
 from spyder.utils.qthelpers import (create_action, create_toolbutton,
                                     add_actions, MENU_SEPARATOR)
 from spyder.widgets.tabs import Tabs
-from spyder.plugins import SpyderPluginWidget
+
+try:
+    # Spyder 4
+    from spyder.api.plugins import SpyderPluginWidget
+except ImportError:
+    # Spyder 3
+    from spyder.plugins import SpyderPluginWidget
 
 # Local imports
 from .utils.nbopen import nbopen, NBServerError
@@ -420,6 +426,11 @@ class NotebookPlugin(SpyderPluginWidget):
             client = self.get_current_client()
         if self.ipyconsole is not None:
             kernel_id = client.get_kernel_id()
+            if not kernel_id:
+                QMessageBox.critical(
+                    self, _('Error opening console'),
+                    _('There is no kernel associated to this notebook.'))
+                return
             self.ipyconsole._create_client_for_kernel(kernel_id, None, None,
                                                       None)
             ipyclient = self.ipyconsole.get_current_client()
